@@ -1,7 +1,15 @@
+from .email.channel import EmailChannel
 from .mms.channel import MMSChannel
 from .rcs.channel import RCSChannel
 from .sms.channel import SMSChannel
 from .web_rtc.channel import WebRtcChannel
 from .whatsapp.channel import WhatsAppChannel
 
-__all__ = ["WhatsAppChannel", "WebRtcChannel", "MMSChannel", "RCSChannel", "SMSChannel"]
+__all__ = [
+    "WhatsAppChannel",
+    "WebRtcChannel",
+    "MMSChannel",
+    "RCSChannel",
+    "SMSChannel",
+    "EmailChannel",
+]
